# vim: set sw=4 ts=4 et:
#
# spec file for package libxdg-basedir
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global _lto_cflags %{?_lto_cflags} -ffat-lto-objects

%define soname 1
Name:           libxdg-basedir
Version:        1.2.3
Release:        1.7
Summary:        XDG Base Directory Specification Library
License:        MIT
Group:          System/Libraries
URL:            https://github.com/devnev/libxdg-basedir/
Source:         https://github.com/devnev/libxdg-basedir/archive/libxdg-basedir-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  doxygen
BuildRequires:  gcc
BuildRequires:  glibc-devel
BuildRequires:  graphviz
BuildRequires:  libtool
BuildRequires:  make
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files

%description
The XDG Base Directory Specification defines where should user files be looked
for by defining one or more base directories relative in with they should be
located.

This library implements functions to list the directories according to the
specification and provides a few higher-level functions.

%package -n %{name}%{soname}
Summary:        XDG Base Directory Specification Library
Group:          System/Libraries

%description -n %{name}%{soname}
The XDG Base Directory Specification defines where should user files be looked
for by defining one or more base directories relative in with they should be
located.

This library implements functions to list the directories according to the
specification and provides a few higher-level functions.

%package -n %{name}-devel
Summary:        XDG Base Directory Specification Library
Group:          Development/Libraries/C and C++
Requires:       %{name}%{soname} = %{version}-%{release}

%description -n %{name}-devel
The XDG Base Directory Specification defines where should user files be looked
for by defining one or more base directories relative in with they should be
located.

This library implements functions to list the directories according to the
specification and provides a few higher-level functions.

%prep
%setup -q -n libxdg-basedir-%{name}-%{version}

%build
autoreconf -fvi
%configure
make %{?_smp_mflags}

%check
make %{?_smp_mflags} check

%install
%make_install
rm "%{buildroot}%{_libdir}/libxdg-basedir.la"

%post   -n libxdg-basedir1 -p /sbin/ldconfig
%postun -n libxdg-basedir1 -p /sbin/ldconfig

%files -n "%{name}%{soname}"
%license COPYING
%{_libdir}/libxdg-basedir.so.%{soname}
%{_libdir}/libxdg-basedir.so.%{soname}.*

%files -n "%{name}-devel"
%{_includedir}/basedir.h
%{_includedir}/basedir_fs.h
%{_libdir}/libxdg-basedir.so
%{_libdir}/libxdg-basedir.a
%{_libdir}/pkgconfig/libxdg-basedir.pc

%changelog
* Sat Dec 11 2021 Dirk Müller <dmueller@suse.com>
- update to 1.2.3:
  * New maintainer
  * build fixes, code cleanups
  * fix overflow bug
* Sun Jan 24 2021 Dirk Müller <dmueller@suse.com>
- update to 1.2.2:
  * Minor documentation fixes.
  * Fix xdgZeroMemory fallback (when memset/bzero aren't available).
  * Update version number and maintainer.
  * Use strdup rather than malloc+strcpy.
  * Fix out-of-date comment.
  * Fix extraneous semicolons and formatting.
  * Free runtimeDirectory memory too
  * Remove trailing whitespace in libxdg-basedir.pc
- drop 0001-Overflow-bug.diff (upstream)
* Mon Dec  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Don't use the lto flags for building static libs.
- Run spec-cleaner
- Update the URL. The previous domain is down.
- Redownload the tarball. the CRC changed.
* Wed Sep 30 2015 lnussel@suse.de
- properly fix buffer overflow in allocation (0001-Overflow-bug.diff)
- fix download url
- enalbe make check
- drop libxdg-basedir-fix_tests.patch
* Sat Oct 27 2012 toganm@opensuse.org
- Removed obsolute patch libxdg-basedir-fixes.patch
  rebased libxdg-basedir-fix_tests.patch to -p1
* Mon Sep 24 2012 toganm@opensuse.org
- cleanup spec to meet guidelines
* Sun Feb 19 2012 pascal.bleser@opensuse.org
- update to 1.2.0
- disable tests, they have a double free
* Mon Jul  5 2010 pascal.bleser@opensuse.org
- update to 1.1.0
- several spec fixes
- added patch to fix all compilation warnings
* Sun Jun 14 2009 pascal.bleser@opensuse.org
- new package
